__all__ = [
    "ABADON_SDK_VERSION",
    "ABADON_LIB_ROUTE_HEADER",
    "ABADON_LIB_SEND_MSG",
    "ABADON_LIB_SERVER_HOST",
]

ABADON_SDK_VERSION = "v0.0.8"

ABADON_LIB_SERVER_HOST = "http://127.0.0.1:6875"
ABADON_LIB_ROUTE_HEADER = "/http_api/v0.0.1"
ABADON_LIB_SEND_MSG = "/event/msg"
